@@ -6,11 +6,11 @@ import copy
 import inspect
 
 def kronecker_product(A: torch.Tensor, B: torch.Tensor): 
-     res = torch.einsum('ac,bkp->bakcp', A, B).view(B.size(0), 
-                                                     A.size(0)*B.size(1), 
-                                                     A.size(1)*B.size(2) 
+    #print(A.size(),B.size(),2)
+    res = torch.einsum('ac,kp->akcp', A, B).view(A.size(0)*B.size(0), 
+                                                     A.size(1)*B.size(1) 
                                                      ) 
-     return res
+    return res
 
 class convert_for_training:
   def convert_train(self,om,trainfunc,data,params,factor):
